<?php
?>
<?php
namespace Joomla\Plugin\Task\Hikashop_massaction\Extension;

use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Factory;
use Joomla\Component\Scheduler\Administrator\Event\ExecuteTaskEvent;
use Joomla\Component\Scheduler\Administrator\Task\Status as TaskStatus;
use Joomla\Component\Scheduler\Administrator\Traits\TaskPluginTrait;
use Joomla\Event\DispatcherInterface;
use Joomla\Event\SubscriberInterface;
use Joomla\Database\DatabaseAwareTrait;
use Joomla\Database\ParameterType;
use Joomla\Filesystem\File;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;
use LogicException;

\defined('_JEXEC') or die;

final class Hikashop_massaction extends CMSPlugin implements SubscriberInterface
{
    use TaskPluginTrait;
	use DatabaseAwareTrait;

    protected const TASKS_MAP = [
        'Hikashop_massaction.hikashop_massaction' => [
            'langConstPrefix' => 'PLG_TASK_HIKASHOP_MASSACTION_HIKASHOP_MASSACTION',
            'form'            => 'hikashop_massaction',
            'method'          => 'hikashop_massaction',
        ],
    ];

    public static function getSubscribedEvents(): array
    {
        return [
            'onTaskOptionsList' => 'advertiseRoutines',
            'onExecuteTask' => 'standardRoutineHandler',
            'onContentPrepareForm' => 'enhanceTaskItemForm',
        ];
    }

    protected $autoloadLanguage = true;

    public function __construct(DispatcherInterface $dispatcher, array $config)
    {
        parent::__construct($dispatcher, $config);
    }

    protected function hikashop_massaction(ExecuteTaskEvent $event): int
    {
        $this->logTask('Launching HikaShop Massaction task...', 'info');
		$db = Factory::getDbo();

		$params = $event->getArgument('params');

        if (!$db) {
            $this->logTask('No DB connection', 'warning');
            return TaskStatus::NO_RUN;
        }

        if (empty($params)) {
            $this->logTask('Params are empty', 'warning');
            return TaskStatus::NO_RUN;
        }

        if (empty($params->massaction)) {
            $this->logTask('Report not selected', 'warning');
            return TaskStatus::NO_RUN;
        }

        $this->logTask('Loading HikaShop', 'info');
        if (!defined('DS'))
            define('DS', DIRECTORY_SEPARATOR);
        if(!include_once(rtrim(JPATH_ADMINISTRATOR,DS).DS.'components'.DS.'com_hikashop'.DS.'helpers'.DS.'helper.php')) {
            $this->logTask('HikaShop is missing', 'warning');
            return TaskStatus::NO_RUN;
        }

        $config = hikashop_config();
        if(version_compare($config->get('version', '1.0'), '5.1.0', '<')) {
            $this->logTask('HikaShop 5.1.0 minimum is required', 'warning');
            return TaskStatus::NO_RUN;
        }
        $elements = array();
        $massactionClass = hikashop_get('class.massaction');
        $massaction = $massactionClass->get((int)$params->massaction);

        if (empty($massaction)) {
            $this->logTask('Massaction with id '. $params->massaction . 'doesn\'t exist', 'warning');
            return TaskStatus::NO_RUN;
        }
        $massactionClass->process($massaction, $elements);

        if(count($massactionClass->report)) {
            foreach($massactionClass->report as $report) {
                $this->logTask($report, 'info');
            }
        }

        $this->logTask('Completed processing HikaShop Massaction.', 'info');

        return TaskStatus::OK;
    }
}
